# Form implementation generated from reading ui file 'normalize.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_normbox(object):
    def setupUi(self, normbox):
        normbox.setObjectName("normbox")
        normbox.resize(1123, 612)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(normbox)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(700, 600))
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.plot = QtWidgets.QHBoxLayout()
        self.plot.setObjectName("plot")
        self.horizontalLayout_5.addLayout(self.plot)
        self.horizontalLayout_3.addWidget(self.groupBox)
        self.line = QtWidgets.QFrame(parent=normbox)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_3.addWidget(self.line)
        self.buttonsgrid = QtWidgets.QGridLayout()
        self.buttonsgrid.setObjectName("buttonsgrid")
        self.load = QtWidgets.QPushButton(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.load.sizePolicy().hasHeightForWidth())
        self.load.setSizePolicy(sizePolicy)
        self.load.setObjectName("load")
        self.buttonsgrid.addWidget(self.load, 17, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.buttonsgrid.addItem(spacerItem, 14, 0, 1, 3)
        self.save = QtWidgets.QPushButton(parent=normbox)
        self.save.setObjectName("save")
        self.buttonsgrid.addWidget(self.save, 19, 0, 1, 3)
        self.trunclabel = QtWidgets.QLabel(parent=normbox)
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        self.trunclabel.setFont(font)
        self.trunclabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
        self.trunclabel.setObjectName("trunclabel")
        self.buttonsgrid.addWidget(self.trunclabel, 6, 0, 1, 3)
        self.loadlabel = QtWidgets.QLabel(parent=normbox)
        self.loadlabel.setText("")
        self.loadlabel.setObjectName("loadlabel")
        self.buttonsgrid.addWidget(self.loadlabel, 20, 0, 1, 1)
        self.truncleftlabel = QtWidgets.QLabel(parent=normbox)
        self.truncleftlabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.truncleftlabel.setObjectName("truncleftlabel")
        self.buttonsgrid.addWidget(self.truncleftlabel, 7, 0, 1, 1)
        self.undo = QtWidgets.QPushButton(parent=normbox)
        self.undo.setObjectName("undo")
        self.buttonsgrid.addWidget(self.undo, 15, 0, 1, 3)
        self.multfactvalue = QtWidgets.QDoubleSpinBox(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.multfactvalue.sizePolicy().hasHeightForWidth())
        self.multfactvalue.setSizePolicy(sizePolicy)
        self.multfactvalue.setDecimals(4)
        self.multfactvalue.setMinimum(-99.99)
        self.multfactvalue.setSingleStep(0.1)
        self.multfactvalue.setProperty("value", 1.0)
        self.multfactvalue.setObjectName("multfactvalue")
        self.buttonsgrid.addWidget(self.multfactvalue, 11, 2, 1, 1)
        self.truncrightvalue = QtWidgets.QDoubleSpinBox(parent=normbox)
        self.truncrightvalue.setDecimals(4)
        self.truncrightvalue.setMaximum(999999999.99)
        self.truncrightvalue.setObjectName("truncrightvalue")
        self.buttonsgrid.addWidget(self.truncrightvalue, 8, 1, 1, 2)
        self.multfactlabel = QtWidgets.QLabel(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.multfactlabel.sizePolicy().hasHeightForWidth())
        self.multfactlabel.setSizePolicy(sizePolicy)
        self.multfactlabel.setObjectName("multfactlabel")
        self.buttonsgrid.addWidget(self.multfactlabel, 11, 0, 1, 2)
        self.plotcont = QtWidgets.QPushButton(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.plotcont.sizePolicy().hasHeightForWidth())
        self.plotcont.setSizePolicy(sizePolicy)
        self.plotcont.setObjectName("plotcont")
        self.buttonsgrid.addWidget(self.plotcont, 12, 0, 1, 3)
        self.label = QtWidgets.QLabel(parent=normbox)
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        self.label.setFont(font)
        self.label.setLineWidth(1)
        self.label.setAlignment(QtCore.Qt.AlignmentFlag.AlignCenter)
        self.label.setObjectName("label")
        self.buttonsgrid.addWidget(self.label, 10, 0, 1, 3)
        self.truncrightlabel = QtWidgets.QLabel(parent=normbox)
        self.truncrightlabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.truncrightlabel.setObjectName("truncrightlabel")
        self.buttonsgrid.addWidget(self.truncrightlabel, 8, 0, 1, 1)
        self.spectrumselect = QtWidgets.QComboBox(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spectrumselect.sizePolicy().hasHeightForWidth())
        self.spectrumselect.setSizePolicy(sizePolicy)
        self.spectrumselect.setObjectName("spectrumselect")
        self.spectrumselect.addItem("")
        self.buttonsgrid.addWidget(self.spectrumselect, 0, 0, 1, 3)
        self.okcancelbutton = QtWidgets.QDialogButtonBox(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.okcancelbutton.sizePolicy().hasHeightForWidth())
        self.okcancelbutton.setSizePolicy(sizePolicy)
        self.okcancelbutton.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.okcancelbutton.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Close)
        self.okcancelbutton.setCenterButtons(False)
        self.okcancelbutton.setObjectName("okcancelbutton")
        self.buttonsgrid.addWidget(self.okcancelbutton, 20, 1, 1, 2)
        self.reload = QtWidgets.QPushButton(parent=normbox)
        self.reload.setObjectName("reload")
        self.buttonsgrid.addWidget(self.reload, 16, 0, 1, 3)
        self.truncate = QtWidgets.QPushButton(parent=normbox)
        self.truncate.setObjectName("truncate")
        self.buttonsgrid.addWidget(self.truncate, 9, 0, 1, 3)
        self.truncleftvalue = QtWidgets.QDoubleSpinBox(parent=normbox)
        self.truncleftvalue.setDecimals(4)
        self.truncleftvalue.setMaximum(999999999.99)
        self.truncleftvalue.setObjectName("truncleftvalue")
        self.buttonsgrid.addWidget(self.truncleftvalue, 7, 1, 1, 2)
        self.norm = QtWidgets.QPushButton(parent=normbox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.norm.sizePolicy().hasHeightForWidth())
        self.norm.setSizePolicy(sizePolicy)
        self.norm.setObjectName("norm")
        self.buttonsgrid.addWidget(self.norm, 13, 0, 1, 3)
        self.horizontalLayout_3.addLayout(self.buttonsgrid)

        self.retranslateUi(normbox)
        self.okcancelbutton.accepted.connect(normbox.accept) # type: ignore
        self.okcancelbutton.rejected.connect(normbox.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(normbox)
        normbox.setTabOrder(self.spectrumselect, self.truncleftvalue)
        normbox.setTabOrder(self.truncleftvalue, self.truncrightvalue)
        normbox.setTabOrder(self.truncrightvalue, self.truncate)
        normbox.setTabOrder(self.truncate, self.multfactvalue)
        normbox.setTabOrder(self.multfactvalue, self.plotcont)
        normbox.setTabOrder(self.plotcont, self.norm)
        normbox.setTabOrder(self.norm, self.undo)
        normbox.setTabOrder(self.undo, self.reload)
        normbox.setTabOrder(self.reload, self.load)
        normbox.setTabOrder(self.load, self.save)

    def retranslateUi(self, normbox):
        _translate = QtCore.QCoreApplication.translate
        normbox.setWindowTitle(_translate("normbox", "Normalize and Truncate Spectra"))
        self.load.setText(_translate("normbox", "Load in MEAFS"))
        self.save.setText(_translate("normbox", "Save to File and load in MEAFS"))
        self.trunclabel.setText(_translate("normbox", "Truncation"))
        self.truncleftlabel.setText(_translate("normbox", "Left"))
        self.undo.setText(_translate("normbox", "Undo All"))
        self.multfactlabel.setText(_translate("normbox", "Multiplication Factor"))
        self.plotcont.setText(_translate("normbox", "Plot Continuum"))
        self.label.setText(_translate("normbox", "Normalization"))
        self.truncrightlabel.setText(_translate("normbox", "Right"))
        self.spectrumselect.setItemText(0, _translate("normbox", "Select Spectrum..."))
        self.reload.setText(_translate("normbox", "Reload from File"))
        self.truncate.setText(_translate("normbox", "Truncate"))
        self.norm.setText(_translate("normbox", "Normalize"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    normbox = QtWidgets.QDialog()
    ui = Ui_normbox()
    ui.setupUi(normbox)
    normbox.show()
    sys.exit(app.exec())
